@@ -89,7 +89,7 @@ def distribute_package(root, version=None, repository=None, *,
     :param version_file: 保存版本号的文件，注意看正则规则，需要满足特定的范式，才会自动更新版本号
     :param delete_dist: 上传完是否自动删除dist目录，要检查上传包是否有遗漏时，要关闭
     """
-    from pyxllib.file.specialist import XlPath
+    from pyxllib.file.specialist import XlPath, File
 
     # 1 切换工作目录
     os.chdir(str(root))
